@@ -1040,7 +1040,7 @@ class ControlQuad8AndRequestData(ISerializable):
 
 
 
-class ControlPosition16(ISerializable):
+class ControlPositionShort(ISerializable):
 
     def __init__(self):
         self.position_x          = 0
@@ -1064,7 +1064,7 @@ class ControlPosition16(ISerializable):
 
     @classmethod
     def parse(cls, data_array):
-        data = ControlPosition16()
+        data = ControlPositionShort()
         
         if len(data_array) != cls.get_size():
             return None
@@ -2917,6 +2917,35 @@ class MotorV(ISerializable):
 
 class MotorSingle(ISerializable):
 
+    def __init__(self):
+        self.target     = 0
+        self.value      = 0
+
+
+    @classmethod
+    def get_size(cls):
+        return 3
+
+
+    def to_array(self):
+        return pack('<Bh', self.target, self.value)
+
+
+    @classmethod
+    def parse(cls, data_array):
+        data = MotorSingle()
+        
+        if len(data_array) != cls.get_size():
+            return None
+        
+        data.target, data.value = unpack('<Bh', data_array)
+        
+        return data
+
+
+
+class MotorSingleRotation(ISerializable):
+
     def __init__(self):
         self.target     = 0
         self.rotation   = Rotation.NONE
@@ -2934,7 +2963,7 @@ class MotorSingle(ISerializable):
 
     @classmethod
     def parse(cls, data_array):
-        data = MotorSingle()
+        data = MotorSingleRotation()
         
         if len(data_array) != cls.get_size():
             return None
@@ -2946,35 +2975,6 @@ class MotorSingle(ISerializable):
 
 
 
-class MotorSingleV(ISerializable):
-
-    def __init__(self):
-        self.target     = 0
-        self.value      = 0
-
-
-    @classmethod
-    def get_size(cls):
-        return 3
-
-
-    def to_array(self):
-        return pack('<Bh', self.target, self.value)
-
-
-    @classmethod
-    def parse(cls, data_array):
-        data = MotorSingleV()
-        
-        if len(data_array) != cls.get_size():
-            return None
-        
-        data.target, data.value = unpack('<Bh', data_array)
-        
-        return data
-
-
-
 class InformationAssembledForController(ISerializable):
 
     def __init__(self):
